<?php
/**
 * Custom widgets.
 *
 * @package basic_blog
 */
if ( !class_exists( 'basic_blog_carousel_widget' ) ) :

	/**
	 * Two Column News widget class.
	 *
	 * @since 1.0.0
	 */
	class basic_blog_carousel_widget extends WP_Widget {

		function __construct() {
			$opts = array(
				'classname'		 => 'carousel-news-section',
				'description'	 => esc_html__( 'Widget to display carousel.', 'basic-blog' ),
			);

			parent::__construct( 'carousel-news-section', esc_html__( 'Basic Blog: Carousel', 'basic-blog' ), $opts );
		}

		function widget( $args, $instance ) {

			$mix_category = !empty( $instance[ 'mix_category' ] ) ? $instance[ 'mix_category' ] : 0;

			$post_number = !empty( $instance[ 'post_number' ] ) ? $instance[ 'post_number' ] : 5;

			echo $args[ 'before_widget' ];
			?>

			
				<div class="inner-wrapper slick-slider-section bb-carousel-center">
					<?php
					$mix_args = array(
						'posts_per_page'		 => absint( $post_number ),
						'no_found_rows'			 => true,
						'post__not_in'			 => get_option( 'sticky_posts' ),
						'ignore_sticky_posts'	 => true,
					);

					if ( absint( $mix_category ) > 0 ) {
						$mix_args[ 'cat' ] = absint( $mix_category );
					}


					$mix_posts = new WP_Query( $mix_args );

					if ( $mix_posts->have_posts() ) :

						$mix_col_count = 1;

						while ( $mix_posts->have_posts() ) :

							$mix_posts->the_post();
							?>

							<div class="news-item carousel-news-item">
								<?php basic_blog_thumb_img( 'basic-blog-archive' ); ?>
								<?php if ( has_post_thumbnail() ) { ?>
								<div class="absolute-wrap">
								<?php } else { ?>
								<div class="relative-wrap">	
								<?php } ?>	
									<h2>
										<a href="<?php the_permalink(); ?>">
											<?php the_title(); ?>
										</a>
									</h2>
									<?php
									$categories_list = get_the_category_list( ' ' );
									// Make sure there's more than one category before displaying.
									if ( $categories_list ) {
										echo '<div class="cat-links">' . $categories_list . '</div>';
									}
									?>
									<span class="author-meta">
										<span class="author-meta-by"><?php esc_html_e( 'By', 'basic-blog' ); ?></span>
										<a href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ), get_the_author_meta( 'user_nicename' ) ) ); ?>">
											<?php the_author(); ?>
										</a>
									</span>
									<?php basic_blog_widget_date_comments(); ?>

								</div><!-- .news-text-wrap -->
							</div><!-- .news-item -->

							<?php
							$mix_col_count++;

						endwhile;

						wp_reset_postdata();
						?>
					<?php endif; ?>
				</div><!-- .inner-wrapper -->

			</div><!-- .mix-column-news -->

			<?php
			echo $args[ 'after_widget' ];
		}

		function update( $new_instance, $old_instance ) {
			$instance						 = $old_instance;
			$instance[ 'mix_category' ]		 = absint( $new_instance[ 'mix_category' ] );
			$instance[ 'post_number' ]		 = absint( $new_instance[ 'post_number' ] );

			return $instance;
		}

		function form( $instance ) {

			$instance	 = wp_parse_args( (array) $instance, array(
				'mix_category'	 => '',
				'post_number'	 => 5,
			) );
			?>

			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'mix_category' ) ); ?>"><strong><?php esc_html_e( 'Category:', 'basic-blog' ); ?></strong></label>
				<?php
				$cat_args	 = array(
					'orderby'			 => 'name',
					'hide_empty'		 => 0,
					'class'				 => 'widefat',
					'taxonomy'			 => 'category',
					'name'				 => $this->get_field_name( 'mix_category' ),
					'id'				 => $this->get_field_id( 'mix_category' ),
					'selected'			 => absint( $instance[ 'mix_category' ] ),
					'show_option_all'	 => esc_html__( 'All Categories', 'basic-blog' ),
				);
				wp_dropdown_categories( $cat_args );
				?>
			</p>

			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'post_number' ) ); ?>"><strong><?php esc_html_e( 'Number of Posts:', 'basic-blog' ); ?></strong></label>
				<?php
				$this->dropdown_post_number( array(
					'id'		 => $this->get_field_id( 'post_number' ),
					'name'		 => $this->get_field_name( 'post_number' ),
					'selected'	 => absint( $instance[ 'post_number' ] ),
				)
				);
				?>
			</p>

			<?php
		}

		function dropdown_post_number( $args ) {
			$defaults = array(
				'id'		 => '',
				'name'		 => '',
				'selected'	 => 0,
			);

			$r		 = wp_parse_args( $args, $defaults );
			$output	 = '';

			$choices = array(
				'5'	 => 5,
				'6'	 => 6,
				'7'	 => 7,
				'8'	 => 8,
				'9'	 => 9,
				'10' => 10,
				'11' => 11,
				'12' => 12,
				'13' => 13,
				'14' => 14,
				'15' => 15,
				'16' => 16,
			);

			if ( !empty( $choices ) ) {

				$output = "<select name='" . esc_attr( $r[ 'name' ] ) . "' id='" . esc_attr( $r[ 'id' ] ) . "'>\n";
				foreach ( $choices as $key => $choice ) {
					$output .= '<option value="' . esc_attr( $key ) . '" ';
					$output .= selected( $r[ 'selected' ], $key, false );
					$output .= '>' . esc_html( $choice ) . '</option>\n';
				}
				$output .= "</select>\n";
			}

			echo $output;
		}

	}	

endif;
